package com.xinelu.manage.service.subscribemessagerecord;

import com.xinelu.manage.domain.subscribemessagerecord.SubscribeMessageRecord;

import java.util.List;

/**
 * 微信小程序订阅消息记录Service接口
 *
 * @author xinelu
 * @date 2024-03-19
 */
public interface ISubscribeMessageRecordService {
    /**
     * 查询微信小程序订阅消息记录
     *
     * @param id 微信小程序订阅消息记录主键
     * @return 微信小程序订阅消息记录
     */
    SubscribeMessageRecord selectSubscribeMessageRecordById(Long id);

    /**
     * 查询微信小程序订阅消息记录列表
     *
     * @param subscribeMessageRecord 微信小程序订阅消息记录
     * @return 微信小程序订阅消息记录集合
     */
    List<SubscribeMessageRecord> selectSubscribeMessageRecordList(SubscribeMessageRecord subscribeMessageRecord);

    /**
     * 新增微信小程序订阅消息记录
     *
     * @param subscribeMessageRecord 微信小程序订阅消息记录
     * @return 结果
     */
    int insertSubscribeMessageRecord(SubscribeMessageRecord subscribeMessageRecord);

    /**
     * 修改微信小程序订阅消息记录
     *
     * @param subscribeMessageRecord 微信小程序订阅消息记录
     * @return 结果
     */
    int updateSubscribeMessageRecord(SubscribeMessageRecord subscribeMessageRecord);

    /**
     * 批量删除微信小程序订阅消息记录
     *
     * @param ids 需要删除的微信小程序订阅消息记录主键集合
     * @return 结果
     */
    int deleteSubscribeMessageRecordByIds(Long[] ids);

    /**
     * 删除微信小程序订阅消息记录信息
     *
     * @param id 微信小程序订阅消息记录主键
     * @return 结果
     */
    int deleteSubscribeMessageRecordById(Long id);
}
